# Table of Contents

- [initiating-integration-api-runs-with-python](<./initiating-integration-api-runs-with-python.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Initiating Integration API Runs with Python](<./Initiating-Integration-API-Runs-with-Python.md>)
  - [Overview](<./Initiating-Integration-API-Runs-with-Python/Overview.md>)
  - [Prerequisites](<./Initiating-Integration-API-Runs-with-Python/Prerequisites.md>)
  - [Initial Script Setup](<./Initiating-Integration-API-Runs-with-Python/Initial-Script-Setup.md>)
  - [Adjust Connector Variables](<./Initiating-Integration-API-Runs-with-Python/Adjust-Connector-Variables.md>)
  - [Adapt for Inbound](<./Initiating-Integration-API-Runs-with-Python/Adapt-for-Inbound.md>)
  - [Was this page helpful?](<./Initiating-Integration-API-Runs-with-Python/Was-this-page-helpful.md>)
